@@ -135,7 +135,7 @@ class NvdSource(VulnerabilitySource):
         # Issue 12 - Ignore disputed vulnerabilities
         if "** DISPUTED **" in description:
             return None
-        rdata = vuln["cve"]["references"]["reference_data"]
+        rdata = vuln.get("cve", {}).get("references", {}).get("reference_data", [])
         related_urls = [r["url"] for r in rdata]
         if "baseMetricV3" in vuln["impact"]:
             cvss_data = vuln["impact"]["baseMetricV3"]["cvssV3"]
@@ -193,7 +193,9 @@ class NvdSource(VulnerabilitySource):
             fix_cpe_uri = None
             for cpe in cpe_list:
                 detail = {}
-                if cpe["vulnerable"]:
+                if not cpe.get("cpe23Uri"):
+                    continue
+                if cpe["vulnerable"] and cpe.get("cpe23Uri"):
                     detail["cpe_uri"] = cpe["cpe23Uri"]
                     detail["min_affected_version_including"] = cpe.get(
                         "versionStartIncluding"
@@ -209,7 +211,7 @@ class NvdSource(VulnerabilitySource):
                     )
                     detail["source_update_time"] = vuln["lastModifiedDate"]
                     cpe_details_list.append(detail)
-                else: # cpe is not vulnerable
+                else:  # cpe is not vulnerable
                     if node["operator"] == "OR":
                         fix_cpe_uri = cpe["cpe23Uri"]
             # Add fix version details
