@@ -17,25 +17,27 @@ def store(datas, db_file=config.vdb_bin_file, index_file=config.vdb_bin_index):
     data_list = serialize_vuln_list(datas)
     index_list = []
     for data in data_list:
-        vendor, _, _ = parse_cpe(data["details"]["cpe_uri"])
-        index_list.append(
-            {
-                "vendor": vendor.lower(),
-                "name": data["details"]["package"].lower(),
-                "min_affected_version_including": data["details"].get(
-                    "min_affected_version_including"
-                ),
-                "max_affected_version_including": data["details"].get(
-                    "max_affected_version_including"
-                ),
-                "min_affected_version_excluding": data["details"].get(
-                    "min_affected_version_excluding"
-                ),
-                "max_affected_version_excluding": data["details"].get(
-                    "max_affected_version_excluding"
-                ),
-            }
-        )
+        if data["details"]["cpe_uri"]:
+            vendor, _, _ = parse_cpe(data["details"]["cpe_uri"])
+            if vendor:
+                index_list.append(
+                    {
+                        "vendor": vendor.lower(),
+                        "name": data["details"]["package"].lower(),
+                        "min_affected_version_including": data["details"].get(
+                            "min_affected_version_including"
+                        ),
+                        "max_affected_version_including": data["details"].get(
+                            "max_affected_version_including"
+                        ),
+                        "min_affected_version_excluding": data["details"].get(
+                            "min_affected_version_excluding"
+                        ),
+                        "max_affected_version_excluding": data["details"].get(
+                            "max_affected_version_excluding"
+                        ),
+                    }
+                )
     packed_obj = msgpack.packb(data_list, use_bin_type=True)
     with open(db_file, mode="ab") as fp:
         fp.write(packed_obj)
