@@ -501,7 +501,10 @@ def parse_cpe(cpe_uri):
     :return: Individual parts
     """
     parts = CPE_REGEX.match(cpe_uri)
-    return parts.group("vendor"), parts.group("package"), parts.group("version")
+    if parts:
+        return parts.group("vendor"), parts.group("package"), parts.group("version")
+    else:
+        return "", None, None
 
 
 def get_default_cve_data(severity):
